"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var initialConfig = {
    endTime: null,
    initialTime: 0,
    interval: 1000,
    step: 1,
    timerType: 'INCREMENTAL',
};
exports.useTimer = function (config) {
    var _a = __assign({}, initialConfig, config), endTime = _a.endTime, initialTime = _a.initialTime, interval = _a.interval, step = _a.step, timerType = _a.timerType;
    var intervalRef = react_1.useRef(null);
    var pausedTimeRef = react_1.useRef(null);
    var timeoutRef = react_1.useRef(null);
    var _b = react_1.useState(false), shouldResetTime = _b[0], setShouldResetTime = _b[1];
    var _c = react_1.useState(initialTime), time = _c[0], setTime = _c[1];
    var cancelTimers = function () {
        cancelInterval();
        cancelTimeout();
    };
    var cancelInterval = function () {
        if (intervalRef.current) {
            clearInterval(intervalRef.current);
            intervalRef.current = null;
        }
    };
    var cancelTimeout = function () {
        if (timeoutRef.current) {
            clearTimeout(timeoutRef.current);
            timeoutRef.current = null;
        }
    };
    var createInterval = function () {
        intervalRef.current = setInterval(function () {
            setTime(function (previousTime) {
                return timerType === 'INCREMENTAL' ? previousTime + step : previousTime - step;
            });
        }, interval);
    };
    var createTimeout = function () {
        if (endTime === null) {
            return;
        }
        var delay = Math.abs(endTime - (pausedTimeRef.current || initialTime)) * interval;
        timeoutRef.current = setTimeout(function () {
            cancelInterval();
            setShouldResetTime(true);
        }, delay);
    };
    var pause = function () {
        pausedTimeRef.current = time;
        cancelTimers();
    };
    var reset = function () {
        pausedTimeRef.current = null;
        cancelTimers();
        resetTime();
    };
    var resetTime = function () {
        setTime(initialTime);
    };
    var start = function () {
        if (intervalRef.current) {
            return;
        }
        if (shouldResetTime) {
            resetTime();
            setShouldResetTime(false);
        }
        createInterval();
        createTimeout();
    };
    react_1.useEffect(function () { return cancelTimers; }, []);
    return { pause: pause, reset: reset, start: start, time: time };
};
